# Tools for working with Data Packages and CKAN

[![Travis](https://img.shields.io/travis/frictionlessdata/ckan-datapackage-tools/master.svg)](https://travis-ci.org/frictionlessdata/ckan-datapackage-tools)
[![Coveralls](http://img.shields.io/coveralls/frictionlessdata/ckan-datapackage-tools/master.svg)](https://coveralls.io/r/frictionlessdata/ckan-datapackage-tools?branch=master)
[![PyPi](https://img.shields.io/pypi/v/ckan-datapackage-tools.svg)](https://pypi.python.org/pypi/ckan-datapackage-tools)
[![SemVer](https://img.shields.io/badge/versions-SemVer-brightgreen.svg)](http://semver.org/)
[![Gitter](https://img.shields.io/gitter/room/frictionlessdata/chat.svg)](https://gitter.im/frictionlessdata/chat)

## Install

```
# clone the repo and install it with pip

git clone https://github.com/frictionlessdata/ckan-datapackage-tools.git
pip install -e .
```

## Usage
